@@ -14,12 +14,12 @@ cd $srcdir
 
 # Use the style-checker as pre-commit and pre-applypatch hooks
 if [ -d $srcdir/.git ]; then
-        if [ ! -L $srcdir/.git/hooks/pre-commit ]; then
-            ln -s ../../../libgames-support/style-checker $srcdir/.git/hooks/pre-commit && echo "Enabled pre-commit style checker." || :
-        fi
-        if [ ! -L $srcdir/.git/hooks/pre-applypatch ]; then
-            ln -s ../../../libgames-support/style-checker $srcdir/.git/hooks/pre-applypatch && echo "Enabled pre-applypatch style checker." || :
-        fi
+	for HOOK in pre-commit pre-applypatch; do
+                if [ ! -L $srcdir/.git/hooks/$HOOK ]; then
+                        ln -s ../../../libgnome-games-support/style-checker \
+                                $srcdir/.git/hooks/$HOOK && echo "Enabled $HOOK style checker."
+                fi
+        done
 fi
 
 PKG_NAME=`autoconf --trace 'AC_INIT:$1' configure.ac`
